pub trait ExecutionManager { // Required method fn stop(&mut self); }
Execution manager used to stop the execution thread
Stop the execution thread Note that we do not take self by value to consume it because it is not allowed to move out of Box<dyn ExecutionManager> This will improve if the unsized_fn_params feature stabilizes enough to be safely usable.
Box<dyn ExecutionManager>
unsized_fn_params